==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment.md <==
# AwsTransitGatewayAttachment


```text
aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment
```

```text
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment')
```



| Illustration | AwsTransitGatewayAttachment | AwsTransitGatewayAttachmentCard | AwsTransitGatewayAttachmentGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment.png) | ![illustration for AwsTransitGatewayAttachment](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment.Local.png) | ![illustration for AwsTransitGatewayAttachmentCard](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachmentCard.Local.png) | ![illustration for AwsTransitGatewayAttachmentGroup](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachmentGroup.Local.png) |




## AwsTransitGatewayAttachment

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransitGatewayAttachment
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment')

' renders the element
AwsTransitGatewayAttachment('AwsTransitGatewayAttachment', 'Aws Transit Gateway Attachment', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransitGatewayAttachment
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment')

' renders the element
AwsTransitGatewayAttachment('AwsTransitGatewayAttachment', 'Aws Transit Gateway Attachment', 'an optional tech label')
@enduml
```

## AwsTransitGatewayAttachmentCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransitGatewayAttachmentCard
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment')

' renders the element
AwsTransitGatewayAttachmentCard('AwsTransitGatewayAttachmentCard', 'Aws Transit Gateway Attachment Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransitGatewayAttachmentCard
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment')

' renders the element
AwsTransitGatewayAttachmentCard('AwsTransitGatewayAttachmentCard', 'Aws Transit Gateway Attachment Card', 'an optional description')
@enduml
```

## AwsTransitGatewayAttachmentGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransitGatewayAttachmentGroup
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment')

' renders the element
AwsTransitGatewayAttachmentGroup('AwsTransitGatewayAttachmentGroup', 'Aws Transit Gateway Attachment Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransitGatewayAttachmentGroup
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment')

' renders the element
AwsTransitGatewayAttachmentGroup('AwsTransitGatewayAttachmentGroup', 'Aws Transit Gateway Attachment Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment.md <==
# AwsTransitGatewayAttachment


```text
aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment
```

```text
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment')
```



| Illustration | AwsTransitGatewayAttachment | AwsTransitGatewayAttachmentCard | AwsTransitGatewayAttachmentGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment.png) | ![illustration for AwsTransitGatewayAttachment](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment.Local.png) | ![illustration for AwsTransitGatewayAttachmentCard](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachmentCard.Local.png) | ![illustration for AwsTransitGatewayAttachmentGroup](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachmentGroup.Local.png) |




## AwsTransitGatewayAttachment

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransitGatewayAttachment
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment')

' renders the element
AwsTransitGatewayAttachment('AwsTransitGatewayAttachment', 'Aws Transit Gateway Attachment', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransitGatewayAttachment
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment')

' renders the element
AwsTransitGatewayAttachment('AwsTransitGatewayAttachment', 'Aws Transit Gateway Attachment', 'an optional tech label', 'an optional description')
@enduml
```

## AwsTransitGatewayAttachmentCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransitGatewayAttachmentCard
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment')

' renders the element
AwsTransitGatewayAttachmentCard('AwsTransitGatewayAttachmentCard', 'Aws Transit Gateway Attachment Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransitGatewayAttachmentCard
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment')

' renders the element
AwsTransitGatewayAttachmentCard('AwsTransitGatewayAttachmentCard', 'Aws Transit Gateway Attachment Card', 'an optional description')
@enduml
```

## AwsTransitGatewayAttachmentGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransitGatewayAttachmentGroup
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment')

' renders the element
AwsTransitGatewayAttachmentGroup('AwsTransitGatewayAttachmentGroup', 'Aws Transit Gateway Attachment Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsTransitGatewayAttachmentGroup
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AwsTransitGatewayAttachment')

' renders the element
AwsTransitGatewayAttachmentGroup('AwsTransitGatewayAttachmentGroup', 'Aws Transit Gateway Attachment Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
